hgext/pager.py
branchstable
changeset 12083 ebfc46929f3e
parent 11414 0fa4474bdc2f
child 12694 04f6de46bf3a
--- a/hgext/pager.py	Sun Aug 29 23:16:31 2010 +0200
+++ b/hgext/pager.py	Fri Aug 27 22:36:35 2010 -0400
@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 #
 # To load the extension, add it to your .hgrc file:
 #
 #   [extension]
 #   pager =
@@ -46,7 +46,7 @@
 If pager.attend is present, pager.ignore will be ignored.
 
 To ignore global commands like :hg:`version` or :hg:`help`, you have
-to specify them in the global .hgrc
+to specify them in your user configuration file.
 '''
 
 import sys, os, signal, shlex, errno
@@ -5,7 +5,7 @@
 # GNU General Public License version 2 or any later version.
 #
-# To load the extension, add it to your .hgrc file:
+# To load the extension, add it to your configuration file:
 #
 #   [extension]